# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_road.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2
from modules.map.proto import map_id_pb2 as modules_dot_map_dot_proto_dot_map__id__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_road.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n modules/map/proto/map_road.proto\x12\x0c\x61pollo.hdmap\x1a$modules/map/proto/map_geometry.proto\x1a\x1emodules/map/proto/map_id.proto\"\xa9\x01\n\x0c\x42oundaryEdge\x12\"\n\x05\x63urve\x18\x01 \x01(\x0b\x32\x13.apollo.hdmap.Curve\x12-\n\x04type\x18\x02 \x01(\x0e\x32\x1f.apollo.hdmap.BoundaryEdge.Type\"F\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06NORMAL\x10\x01\x12\x11\n\rLEFT_BOUNDARY\x10\x02\x12\x12\n\x0eRIGHT_BOUNDARY\x10\x03\";\n\x0f\x42oundaryPolygon\x12(\n\x04\x65\x64ge\x18\x01 \x03(\x0b\x32\x1a.apollo.hdmap.BoundaryEdge\"q\n\x0cRoadBoundary\x12\x34\n\router_polygon\x18\x01 \x01(\x0b\x32\x1d.apollo.hdmap.BoundaryPolygon\x12+\n\x04hole\x18\x02 \x03(\x0b\x32\x1d.apollo.hdmap.BoundaryPolygon\"d\n\x0fRoadROIBoundary\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12\x33\n\x0froad_boundaries\x18\x02 \x03(\x0b\x32\x1a.apollo.hdmap.RoadBoundary\"|\n\x0bRoadSection\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12!\n\x07lane_id\x18\x02 \x03(\x0b\x32\x10.apollo.hdmap.Id\x12,\n\x08\x62oundary\x18\x03 \x01(\x0b\x32\x1a.apollo.hdmap.RoadBoundary\"\xd9\x01\n\x04Road\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12*\n\x07section\x18\x02 \x03(\x0b\x32\x19.apollo.hdmap.RoadSection\x12%\n\x0bjunction_id\x18\x03 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12%\n\x04type\x18\x04 \x01(\x0e\x32\x17.apollo.hdmap.Road.Type\"9\n\x04Type\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07HIGHWAY\x10\x01\x12\r\n\tCITY_ROAD\x10\x02\x12\x08\n\x04PARK\x10\x03'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__id__pb2.DESCRIPTOR,])



_BOUNDARYEDGE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.hdmap.BoundaryEdge.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NORMAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LEFT_BOUNDARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RIGHT_BOUNDARY', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=220,
  serialized_end=290,
)
_sym_db.RegisterEnumDescriptor(_BOUNDARYEDGE_TYPE)

_ROAD_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='apollo.hdmap.Road.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HIGHWAY', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CITY_ROAD', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='PARK', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=857,
  serialized_end=914,
)
_sym_db.RegisterEnumDescriptor(_ROAD_TYPE)


_BOUNDARYEDGE = _descriptor.Descriptor(
  name='BoundaryEdge',
  full_name='apollo.hdmap.BoundaryEdge',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='curve', full_name='apollo.hdmap.BoundaryEdge.curve', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.hdmap.BoundaryEdge.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BOUNDARYEDGE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=290,
)


_BOUNDARYPOLYGON = _descriptor.Descriptor(
  name='BoundaryPolygon',
  full_name='apollo.hdmap.BoundaryPolygon',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='edge', full_name='apollo.hdmap.BoundaryPolygon.edge', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=292,
  serialized_end=351,
)


_ROADBOUNDARY = _descriptor.Descriptor(
  name='RoadBoundary',
  full_name='apollo.hdmap.RoadBoundary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='outer_polygon', full_name='apollo.hdmap.RoadBoundary.outer_polygon', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='hole', full_name='apollo.hdmap.RoadBoundary.hole', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=353,
  serialized_end=466,
)


_ROADROIBOUNDARY = _descriptor.Descriptor(
  name='RoadROIBoundary',
  full_name='apollo.hdmap.RoadROIBoundary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.RoadROIBoundary.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='road_boundaries', full_name='apollo.hdmap.RoadROIBoundary.road_boundaries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=568,
)


_ROADSECTION = _descriptor.Descriptor(
  name='RoadSection',
  full_name='apollo.hdmap.RoadSection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.RoadSection.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_id', full_name='apollo.hdmap.RoadSection.lane_id', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='boundary', full_name='apollo.hdmap.RoadSection.boundary', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=570,
  serialized_end=694,
)


_ROAD = _descriptor.Descriptor(
  name='Road',
  full_name='apollo.hdmap.Road',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.Road.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='section', full_name='apollo.hdmap.Road.section', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_id', full_name='apollo.hdmap.Road.junction_id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='apollo.hdmap.Road.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _ROAD_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=914,
)

_BOUNDARYEDGE.fields_by_name['curve'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._CURVE
_BOUNDARYEDGE.fields_by_name['type'].enum_type = _BOUNDARYEDGE_TYPE
_BOUNDARYEDGE_TYPE.containing_type = _BOUNDARYEDGE
_BOUNDARYPOLYGON.fields_by_name['edge'].message_type = _BOUNDARYEDGE
_ROADBOUNDARY.fields_by_name['outer_polygon'].message_type = _BOUNDARYPOLYGON
_ROADBOUNDARY.fields_by_name['hole'].message_type = _BOUNDARYPOLYGON
_ROADROIBOUNDARY.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_ROADROIBOUNDARY.fields_by_name['road_boundaries'].message_type = _ROADBOUNDARY
_ROADSECTION.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_ROADSECTION.fields_by_name['lane_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_ROADSECTION.fields_by_name['boundary'].message_type = _ROADBOUNDARY
_ROAD.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_ROAD.fields_by_name['section'].message_type = _ROADSECTION
_ROAD.fields_by_name['junction_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_ROAD.fields_by_name['type'].enum_type = _ROAD_TYPE
_ROAD_TYPE.containing_type = _ROAD
DESCRIPTOR.message_types_by_name['BoundaryEdge'] = _BOUNDARYEDGE
DESCRIPTOR.message_types_by_name['BoundaryPolygon'] = _BOUNDARYPOLYGON
DESCRIPTOR.message_types_by_name['RoadBoundary'] = _ROADBOUNDARY
DESCRIPTOR.message_types_by_name['RoadROIBoundary'] = _ROADROIBOUNDARY
DESCRIPTOR.message_types_by_name['RoadSection'] = _ROADSECTION
DESCRIPTOR.message_types_by_name['Road'] = _ROAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BoundaryEdge = _reflection.GeneratedProtocolMessageType('BoundaryEdge', (_message.Message,), {
  'DESCRIPTOR' : _BOUNDARYEDGE,
  '__module__' : 'modules.map.proto.map_road_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.BoundaryEdge)
  })
_sym_db.RegisterMessage(BoundaryEdge)

BoundaryPolygon = _reflection.GeneratedProtocolMessageType('BoundaryPolygon', (_message.Message,), {
  'DESCRIPTOR' : _BOUNDARYPOLYGON,
  '__module__' : 'modules.map.proto.map_road_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.BoundaryPolygon)
  })
_sym_db.RegisterMessage(BoundaryPolygon)

RoadBoundary = _reflection.GeneratedProtocolMessageType('RoadBoundary', (_message.Message,), {
  'DESCRIPTOR' : _ROADBOUNDARY,
  '__module__' : 'modules.map.proto.map_road_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.RoadBoundary)
  })
_sym_db.RegisterMessage(RoadBoundary)

RoadROIBoundary = _reflection.GeneratedProtocolMessageType('RoadROIBoundary', (_message.Message,), {
  'DESCRIPTOR' : _ROADROIBOUNDARY,
  '__module__' : 'modules.map.proto.map_road_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.RoadROIBoundary)
  })
_sym_db.RegisterMessage(RoadROIBoundary)

RoadSection = _reflection.GeneratedProtocolMessageType('RoadSection', (_message.Message,), {
  'DESCRIPTOR' : _ROADSECTION,
  '__module__' : 'modules.map.proto.map_road_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.RoadSection)
  })
_sym_db.RegisterMessage(RoadSection)

Road = _reflection.GeneratedProtocolMessageType('Road', (_message.Message,), {
  'DESCRIPTOR' : _ROAD,
  '__module__' : 'modules.map.proto.map_road_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Road)
  })
_sym_db.RegisterMessage(Road)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/qos_profile.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/qos_profile.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1d\x63yber/proto/qos_profile.proto\x12\x12\x61pollo.cyber.proto\"\x9f\x02\n\nQosProfile\x12H\n\x07history\x18\x01 \x01(\x0e\x32$.apollo.cyber.proto.QosHistoryPolicy:\x11HISTORY_KEEP_LAST\x12\x10\n\x05\x64\x65pth\x18\x02 \x01(\r:\x01\x31\x12\x0e\n\x03mps\x18\x03 \x01(\r:\x01\x30\x12S\n\x0breliability\x18\x04 \x01(\x0e\x32(.apollo.cyber.proto.QosReliabilityPolicy:\x14RELIABILITY_RELIABLE\x12P\n\ndurability\x18\x05 \x01(\x0e\x32\'.apollo.cyber.proto.QosDurabilityPolicy:\x13\x44URABILITY_VOLATILE*[\n\x10QosHistoryPolicy\x12\x1a\n\x16HISTORY_SYSTEM_DEFAULT\x10\x00\x12\x15\n\x11HISTORY_KEEP_LAST\x10\x01\x12\x14\n\x10HISTORY_KEEP_ALL\x10\x02*m\n\x14QosReliabilityPolicy\x12\x1e\n\x1aRELIABILITY_SYSTEM_DEFAULT\x10\x00\x12\x18\n\x14RELIABILITY_RELIABLE\x10\x01\x12\x1b\n\x17RELIABILITY_BEST_EFFORT\x10\x02*m\n\x13QosDurabilityPolicy\x12\x1d\n\x19\x44URABILITY_SYSTEM_DEFAULT\x10\x00\x12\x1e\n\x1a\x44URABILITY_TRANSIENT_LOCAL\x10\x01\x12\x17\n\x13\x44URABILITY_VOLATILE\x10\x02'
)

_QOSHISTORYPOLICY = _descriptor.EnumDescriptor(
  name='QosHistoryPolicy',
  full_name='apollo.cyber.proto.QosHistoryPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='HISTORY_SYSTEM_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HISTORY_KEEP_LAST', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='HISTORY_KEEP_ALL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=343,
  serialized_end=434,
)
_sym_db.RegisterEnumDescriptor(_QOSHISTORYPOLICY)

QosHistoryPolicy = enum_type_wrapper.EnumTypeWrapper(_QOSHISTORYPOLICY)
_QOSRELIABILITYPOLICY = _descriptor.EnumDescriptor(
  name='QosReliabilityPolicy',
  full_name='apollo.cyber.proto.QosReliabilityPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RELIABILITY_SYSTEM_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELIABILITY_RELIABLE', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='RELIABILITY_BEST_EFFORT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=436,
  serialized_end=545,
)
_sym_db.RegisterEnumDescriptor(_QOSRELIABILITYPOLICY)

QosReliabilityPolicy = enum_type_wrapper.EnumTypeWrapper(_QOSRELIABILITYPOLICY)
_QOSDURABILITYPOLICY = _descriptor.EnumDescriptor(
  name='QosDurabilityPolicy',
  full_name='apollo.cyber.proto.QosDurabilityPolicy',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='DURABILITY_SYSTEM_DEFAULT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DURABILITY_TRANSIENT_LOCAL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DURABILITY_VOLATILE', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=547,
  serialized_end=656,
)
_sym_db.RegisterEnumDescriptor(_QOSDURABILITYPOLICY)

QosDurabilityPolicy = enum_type_wrapper.EnumTypeWrapper(_QOSDURABILITYPOLICY)
HISTORY_SYSTEM_DEFAULT = 0
HISTORY_KEEP_LAST = 1
HISTORY_KEEP_ALL = 2
RELIABILITY_SYSTEM_DEFAULT = 0
RELIABILITY_RELIABLE = 1
RELIABILITY_BEST_EFFORT = 2
DURABILITY_SYSTEM_DEFAULT = 0
DURABILITY_TRANSIENT_LOCAL = 1
DURABILITY_VOLATILE = 2



_QOSPROFILE = _descriptor.Descriptor(
  name='QosProfile',
  full_name='apollo.cyber.proto.QosProfile',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='history', full_name='apollo.cyber.proto.QosProfile.history', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='depth', full_name='apollo.cyber.proto.QosProfile.depth', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mps', full_name='apollo.cyber.proto.QosProfile.mps', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reliability', full_name='apollo.cyber.proto.QosProfile.reliability', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='durability', full_name='apollo.cyber.proto.QosProfile.durability', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=54,
  serialized_end=341,
)

_QOSPROFILE.fields_by_name['history'].enum_type = _QOSHISTORYPOLICY
_QOSPROFILE.fields_by_name['reliability'].enum_type = _QOSRELIABILITYPOLICY
_QOSPROFILE.fields_by_name['durability'].enum_type = _QOSDURABILITYPOLICY
DESCRIPTOR.message_types_by_name['QosProfile'] = _QOSPROFILE
DESCRIPTOR.enum_types_by_name['QosHistoryPolicy'] = _QOSHISTORYPOLICY
DESCRIPTOR.enum_types_by_name['QosReliabilityPolicy'] = _QOSRELIABILITYPOLICY
DESCRIPTOR.enum_types_by_name['QosDurabilityPolicy'] = _QOSDURABILITYPOLICY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

QosProfile = _reflection.GeneratedProtocolMessageType('QosProfile', (_message.Message,), {
  'DESCRIPTOR' : _QOSPROFILE,
  '__module__' : 'cyber.proto.qos_profile_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.QosProfile)
  })
_sym_db.RegisterMessage(QosProfile)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/dreamview/proto/camera_update.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/dreamview/proto/camera_update.proto',
  package='apollo.dreamview',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n+modules/dreamview/proto/camera_update.proto\x12\x10\x61pollo.dreamview\"o\n\x0c\x43\x61meraUpdate\x12\x14\n\x0clocalization\x18\x01 \x03(\x01\x12\x1e\n\x16localization2camera_tf\x18\x02 \x03(\x01\x12\r\n\x05image\x18\x03 \x01(\x0c\x12\x1a\n\x12image_aspect_ratio\x18\x04 \x01(\x01'
)




_CAMERAUPDATE = _descriptor.Descriptor(
  name='CameraUpdate',
  full_name='apollo.dreamview.CameraUpdate',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='localization', full_name='apollo.dreamview.CameraUpdate.localization', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='localization2camera_tf', full_name='apollo.dreamview.CameraUpdate.localization2camera_tf', index=1,
      number=2, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image', full_name='apollo.dreamview.CameraUpdate.image', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='image_aspect_ratio', full_name='apollo.dreamview.CameraUpdate.image_aspect_ratio', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=65,
  serialized_end=176,
)

DESCRIPTOR.message_types_by_name['CameraUpdate'] = _CAMERAUPDATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CameraUpdate = _reflection.GeneratedProtocolMessageType('CameraUpdate', (_message.Message,), {
  'DESCRIPTOR' : _CAMERAUPDATE,
  '__module__' : 'modules.dreamview.proto.camera_update_pb2'
  # @@protoc_insertion_point(class_scope:apollo.dreamview.CameraUpdate)
  })
_sym_db.RegisterMessage(CameraUpdate)


# @@protoc_insertion_point(module_scope)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/planning/proto/lattice_sampling_config.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/planning/proto/lattice_sampling_config.proto',
  package='apollo.planning',
  syntax='proto2',
  serialized_pb=_b('\n4modules/planning/proto/lattice_sampling_config.proto\x12\x0f\x61pollo.planning\";\n\x0cLonCondition\x12\x0c\n\x01s\x18\x01 \x01(\x01:\x01\x30\x12\r\n\x02\x64s\x18\x02 \x01(\x01:\x01\x30\x12\x0e\n\x03\x64\x64s\x18\x03 \x01(\x01:\x01\x30\";\n\x0cLatCondition\x12\x0c\n\x01l\x18\x01 \x01(\x01:\x01\x30\x12\r\n\x02\x64l\x18\x02 \x01(\x01:\x01\x30\x12\x0e\n\x03\x64\x64l\x18\x03 \x01(\x01:\x01\x30\"E\n\tTStrategy\x12\x11\n\tt_markers\x18\x01 \x03(\x01\x12\x13\n\x06t_step\x18\x02 \x01(\x01:\x03\x30.5\x12\x10\n\x08strategy\x18\x03 \x01(\t\"E\n\tSStrategy\x12\x11\n\ts_markers\x18\x01 \x03(\x01\x12\x13\n\x06s_step\x18\x02 \x01(\x01:\x03\x30.5\x12\x10\n\x08strategy\x18\x03 \x01(\t\"{\n\x0fLonSampleConfig\x12\x38\n\x11lon_end_condition\x18\x01 \x01(\x0b\x32\x1d.apollo.planning.LonCondition\x12.\n\nt_strategy\x18\x02 \x01(\x0b\x32\x1a.apollo.planning.TStrategy\"{\n\x0fLatSampleConfig\x12\x38\n\x11lat_end_condition\x18\x01 \x01(\x0b\x32\x1d.apollo.planning.LatCondition\x12.\n\ns_strategy\x18\x02 \x01(\x0b\x32\x1a.apollo.planning.SStrategy\"\x91\x01\n\x15LatticeSamplingConfig\x12;\n\x11lon_sample_config\x18\x01 \x01(\x0b\x32 .apollo.planning.LonSampleConfig\x12;\n\x11lat_sample_config\x18\x02 \x01(\x0b\x32 .apollo.planning.LatSampleConfig')
)




_LONCONDITION = _descriptor.Descriptor(
  name='LonCondition',
  full_name='apollo.planning.LonCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='s', full_name='apollo.planning.LonCondition.s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ds', full_name='apollo.planning.LonCondition.ds', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dds', full_name='apollo.planning.LonCondition.dds', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=73,
  serialized_end=132,
)


_LATCONDITION = _descriptor.Descriptor(
  name='LatCondition',
  full_name='apollo.planning.LatCondition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='l', full_name='apollo.planning.LatCondition.l', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='dl', full_name='apollo.planning.LatCondition.dl', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ddl', full_name='apollo.planning.LatCondition.ddl', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=134,
  serialized_end=193,
)


_TSTRATEGY = _descriptor.Descriptor(
  name='TStrategy',
  full_name='apollo.planning.TStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='t_markers', full_name='apollo.planning.TStrategy.t_markers', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='t_step', full_name='apollo.planning.TStrategy.t_step', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='apollo.planning.TStrategy.strategy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=195,
  serialized_end=264,
)


_SSTRATEGY = _descriptor.Descriptor(
  name='SStrategy',
  full_name='apollo.planning.SStrategy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='s_markers', full_name='apollo.planning.SStrategy.s_markers', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='s_step', full_name='apollo.planning.SStrategy.s_step', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='strategy', full_name='apollo.planning.SStrategy.strategy', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=266,
  serialized_end=335,
)


_LONSAMPLECONFIG = _descriptor.Descriptor(
  name='LonSampleConfig',
  full_name='apollo.planning.LonSampleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lon_end_condition', full_name='apollo.planning.LonSampleConfig.lon_end_condition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='t_strategy', full_name='apollo.planning.LonSampleConfig.t_strategy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=337,
  serialized_end=460,
)


_LATSAMPLECONFIG = _descriptor.Descriptor(
  name='LatSampleConfig',
  full_name='apollo.planning.LatSampleConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lat_end_condition', full_name='apollo.planning.LatSampleConfig.lat_end_condition', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='s_strategy', full_name='apollo.planning.LatSampleConfig.s_strategy', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=462,
  serialized_end=585,
)


_LATTICESAMPLINGCONFIG = _descriptor.Descriptor(
  name='LatticeSamplingConfig',
  full_name='apollo.planning.LatticeSamplingConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='lon_sample_config', full_name='apollo.planning.LatticeSamplingConfig.lon_sample_config', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lat_sample_config', full_name='apollo.planning.LatticeSamplingConfig.lat_sample_config', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=588,
  serialized_end=733,
)

_LONSAMPLECONFIG.fields_by_name['lon_end_condition'].message_type = _LONCONDITION
_LONSAMPLECONFIG.fields_by_name['t_strategy'].message_type = _TSTRATEGY
_LATSAMPLECONFIG.fields_by_name['lat_end_condition'].message_type = _LATCONDITION
_LATSAMPLECONFIG.fields_by_name['s_strategy'].message_type = _SSTRATEGY
_LATTICESAMPLINGCONFIG.fields_by_name['lon_sample_config'].message_type = _LONSAMPLECONFIG
_LATTICESAMPLINGCONFIG.fields_by_name['lat_sample_config'].message_type = _LATSAMPLECONFIG
DESCRIPTOR.message_types_by_name['LonCondition'] = _LONCONDITION
DESCRIPTOR.message_types_by_name['LatCondition'] = _LATCONDITION
DESCRIPTOR.message_types_by_name['TStrategy'] = _TSTRATEGY
DESCRIPTOR.message_types_by_name['SStrategy'] = _SSTRATEGY
DESCRIPTOR.message_types_by_name['LonSampleConfig'] = _LONSAMPLECONFIG
DESCRIPTOR.message_types_by_name['LatSampleConfig'] = _LATSAMPLECONFIG
DESCRIPTOR.message_types_by_name['LatticeSamplingConfig'] = _LATTICESAMPLINGCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LonCondition = _reflection.GeneratedProtocolMessageType('LonCondition', (_message.Message,), dict(
  DESCRIPTOR = _LONCONDITION,
  __module__ = 'modules.planning.proto.lattice_sampling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LonCondition)
  ))
_sym_db.RegisterMessage(LonCondition)

LatCondition = _reflection.GeneratedProtocolMessageType('LatCondition', (_message.Message,), dict(
  DESCRIPTOR = _LATCONDITION,
  __module__ = 'modules.planning.proto.lattice_sampling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LatCondition)
  ))
_sym_db.RegisterMessage(LatCondition)

TStrategy = _reflection.GeneratedProtocolMessageType('TStrategy', (_message.Message,), dict(
  DESCRIPTOR = _TSTRATEGY,
  __module__ = 'modules.planning.proto.lattice_sampling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.TStrategy)
  ))
_sym_db.RegisterMessage(TStrategy)

SStrategy = _reflection.GeneratedProtocolMessageType('SStrategy', (_message.Message,), dict(
  DESCRIPTOR = _SSTRATEGY,
  __module__ = 'modules.planning.proto.lattice_sampling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.SStrategy)
  ))
_sym_db.RegisterMessage(SStrategy)

LonSampleConfig = _reflection.GeneratedProtocolMessageType('LonSampleConfig', (_message.Message,), dict(
  DESCRIPTOR = _LONSAMPLECONFIG,
  __module__ = 'modules.planning.proto.lattice_sampling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LonSampleConfig)
  ))
_sym_db.RegisterMessage(LonSampleConfig)

LatSampleConfig = _reflection.GeneratedProtocolMessageType('LatSampleConfig', (_message.Message,), dict(
  DESCRIPTOR = _LATSAMPLECONFIG,
  __module__ = 'modules.planning.proto.lattice_sampling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LatSampleConfig)
  ))
_sym_db.RegisterMessage(LatSampleConfig)

LatticeSamplingConfig = _reflection.GeneratedProtocolMessageType('LatticeSamplingConfig', (_message.Message,), dict(
  DESCRIPTOR = _LATTICESAMPLINGCONFIG,
  __module__ = 'modules.planning.proto.lattice_sampling_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.planning.LatticeSamplingConfig)
  ))
_sym_db.RegisterMessage(LatticeSamplingConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/control/proto/mrac_conf.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/control/proto/mrac_conf.proto',
  package='apollo.control',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n%modules/control/proto/mrac_conf.proto\x12\x0e\x61pollo.control\"\xef\x02\n\x08MracConf\x12\x1b\n\x10mrac_model_order\x18\x01 \x01(\x05:\x01\x31\x12\x1f\n\x17reference_time_constant\x18\x02 \x01(\x01\x12#\n\x1breference_natural_frequency\x18\x03 \x01(\x01\x12\x1f\n\x17reference_damping_ratio\x18\x04 \x01(\x01\x12\x1b\n\x13\x61\x64\x61ption_state_gain\x18\x05 \x03(\x01\x12\x1d\n\x15\x61\x64\x61ption_desired_gain\x18\x06 \x01(\x01\x12\x1f\n\x17\x61\x64\x61ption_nonlinear_gain\x18\x07 \x01(\x01\x12\x19\n\x11\x61\x64\x61ption_matrix_p\x18\x08 \x03(\x01\x12 \n\x15mrac_saturation_level\x18\t \x01(\x01:\x01\x31\x12%\n\x1d\x61nti_windup_compensation_gain\x18\n \x03(\x01\x12\x1e\n\x16\x63lamping_time_constant\x18\x0b \x01(\x01'
)




_MRACCONF = _descriptor.Descriptor(
  name='MracConf',
  full_name='apollo.control.MracConf',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mrac_model_order', full_name='apollo.control.MracConf.mrac_model_order', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=True, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_time_constant', full_name='apollo.control.MracConf.reference_time_constant', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_natural_frequency', full_name='apollo.control.MracConf.reference_natural_frequency', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reference_damping_ratio', full_name='apollo.control.MracConf.reference_damping_ratio', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_state_gain', full_name='apollo.control.MracConf.adaption_state_gain', index=4,
      number=5, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_desired_gain', full_name='apollo.control.MracConf.adaption_desired_gain', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_nonlinear_gain', full_name='apollo.control.MracConf.adaption_nonlinear_gain', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='adaption_matrix_p', full_name='apollo.control.MracConf.adaption_matrix_p', index=7,
      number=8, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='mrac_saturation_level', full_name='apollo.control.MracConf.mrac_saturation_level', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='anti_windup_compensation_gain', full_name='apollo.control.MracConf.anti_windup_compensation_gain', index=9,
      number=10, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clamping_time_constant', full_name='apollo.control.MracConf.clamping_time_constant', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=58,
  serialized_end=425,
)

DESCRIPTOR.message_types_by_name['MracConf'] = _MRACCONF
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MracConf = _reflection.GeneratedProtocolMessageType('MracConf', (_message.Message,), {
  'DESCRIPTOR' : _MRACCONF,
  '__module__' : 'modules.control.proto.mrac_conf_pb2'
  # @@protoc_insertion_point(class_scope:apollo.control.MracConf)
  })
_sym_db.RegisterMessage(MracConf)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/v2x/proto/v2x_service_obu_to_car.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.v2x.proto import v2x_obu_traffic_light_pb2 as modules_dot_v2x_dot_proto_dot_v2x__obu__traffic__light__pb2
from modules.v2x.proto import v2x_monitor_pb2 as modules_dot_v2x_dot_proto_dot_v2x__monitor__pb2
from modules.v2x.proto import v2x_obu_rsi_pb2 as modules_dot_v2x_dot_proto_dot_v2x__obu__rsi__pb2
from modules.v2x.proto import v2x_obstacles_pb2 as modules_dot_v2x_dot_proto_dot_v2x__obstacles__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/v2x/proto/v2x_service_obu_to_car.proto',
  package='apollo.v2x',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n.modules/v2x/proto/v2x_service_obu_to_car.proto\x12\napollo.v2x\x1a-modules/v2x/proto/v2x_obu_traffic_light.proto\x1a#modules/v2x/proto/v2x_monitor.proto\x1a#modules/v2x/proto/v2x_obu_rsi.proto\x1a%modules/v2x/proto/v2x_obstacles.proto\"I\n\x0eStatusResponse\x12\x15\n\x06status\x18\x01 \x02(\x08:\x05\x66\x61lse\x12\x0c\n\x04info\x18\x02 \x01(\t\x12\x12\n\nerror_code\x18\x03 \x01(\x03\x32\xbb\x02\n\x08ObuToCar\x12Q\n\x17SendPerceptionObstacles\x12\x18.apollo.v2x.V2XObstacles\x1a\x1a.apollo.v2x.StatusResponse\"\x00\x12T\n\x13SendV2xTrafficLight\x12\x1f.apollo.v2x.obu.ObuTrafficLight\x1a\x1a.apollo.v2x.StatusResponse\"\x00\x12\x42\n\nSendV2xRSI\x12\x16.apollo.v2x.obu.ObuRsi\x1a\x1a.apollo.v2x.StatusResponse\"\x00\x12\x42\n\x0cSendObuAlarm\x12\x14.apollo.v2x.ObuAlarm\x1a\x1a.apollo.v2x.StatusResponse\"\x00'
  ,
  dependencies=[modules_dot_v2x_dot_proto_dot_v2x__obu__traffic__light__pb2.DESCRIPTOR,modules_dot_v2x_dot_proto_dot_v2x__monitor__pb2.DESCRIPTOR,modules_dot_v2x_dot_proto_dot_v2x__obu__rsi__pb2.DESCRIPTOR,modules_dot_v2x_dot_proto_dot_v2x__obstacles__pb2.DESCRIPTOR,])




_STATUSRESPONSE = _descriptor.Descriptor(
  name='StatusResponse',
  full_name='apollo.v2x.StatusResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='apollo.v2x.StatusResponse.status', index=0,
      number=1, type=8, cpp_type=7, label=2,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='info', full_name='apollo.v2x.StatusResponse.info', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_code', full_name='apollo.v2x.StatusResponse.error_code', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=222,
  serialized_end=295,
)

DESCRIPTOR.message_types_by_name['StatusResponse'] = _STATUSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

StatusResponse = _reflection.GeneratedProtocolMessageType('StatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _STATUSRESPONSE,
  '__module__' : 'modules.v2x.proto.v2x_service_obu_to_car_pb2'
  # @@protoc_insertion_point(class_scope:apollo.v2x.StatusResponse)
  })
_sym_db.RegisterMessage(StatusResponse)



_OBUTOCAR = _descriptor.ServiceDescriptor(
  name='ObuToCar',
  full_name='apollo.v2x.ObuToCar',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=298,
  serialized_end=613,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendPerceptionObstacles',
    full_name='apollo.v2x.ObuToCar.SendPerceptionObstacles',
    index=0,
    containing_service=None,
    input_type=modules_dot_v2x_dot_proto_dot_v2x__obstacles__pb2._V2XOBSTACLES,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendV2xTrafficLight',
    full_name='apollo.v2x.ObuToCar.SendV2xTrafficLight',
    index=1,
    containing_service=None,
    input_type=modules_dot_v2x_dot_proto_dot_v2x__obu__traffic__light__pb2._OBUTRAFFICLIGHT,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendV2xRSI',
    full_name='apollo.v2x.ObuToCar.SendV2xRSI',
    index=2,
    containing_service=None,
    input_type=modules_dot_v2x_dot_proto_dot_v2x__obu__rsi__pb2._OBURSI,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SendObuAlarm',
    full_name='apollo.v2x.ObuToCar.SendObuAlarm',
    index=3,
    containing_service=None,
    input_type=modules_dot_v2x_dot_proto_dot_v2x__monitor__pb2._OBUALARM,
    output_type=_STATUSRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_OBUTOCAR)

DESCRIPTOR.services_by_name['ObuToCar'] = _OBUTOCAR

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: cyber/proto/unit_test.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='cyber/proto/unit_test.proto',
  package='apollo.cyber.proto',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x1b\x63yber/proto/unit_test.proto\x12\x12\x61pollo.cyber.proto\"1\n\x08UnitTest\x12\x12\n\nclass_name\x18\x01 \x01(\t\x12\x11\n\tcase_name\x18\x02 \x01(\t\"S\n\x07\x43hatter\x12\x11\n\ttimestamp\x18\x01 \x01(\x04\x12\x17\n\x0flidar_timestamp\x18\x02 \x01(\x04\x12\x0b\n\x03seq\x18\x03 \x01(\x04\x12\x0f\n\x07\x63ontent\x18\x04 \x01(\x0c\"?\n\x10\x43hatterBenchmark\x12\r\n\x05stamp\x18\x01 \x01(\x04\x12\x0b\n\x03seq\x18\x02 \x01(\x04\x12\x0f\n\x07\x63ontent\x18\x03 \x01(\t'
)




_UNITTEST = _descriptor.Descriptor(
  name='UnitTest',
  full_name='apollo.cyber.proto.UnitTest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='class_name', full_name='apollo.cyber.proto.UnitTest.class_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='case_name', full_name='apollo.cyber.proto.UnitTest.case_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=51,
  serialized_end=100,
)


_CHATTER = _descriptor.Descriptor(
  name='Chatter',
  full_name='apollo.cyber.proto.Chatter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='apollo.cyber.proto.Chatter.timestamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lidar_timestamp', full_name='apollo.cyber.proto.Chatter.lidar_timestamp', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='apollo.cyber.proto.Chatter.seq', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='apollo.cyber.proto.Chatter.content', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=102,
  serialized_end=185,
)


_CHATTERBENCHMARK = _descriptor.Descriptor(
  name='ChatterBenchmark',
  full_name='apollo.cyber.proto.ChatterBenchmark',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='stamp', full_name='apollo.cyber.proto.ChatterBenchmark.stamp', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='seq', full_name='apollo.cyber.proto.ChatterBenchmark.seq', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='content', full_name='apollo.cyber.proto.ChatterBenchmark.content', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=187,
  serialized_end=250,
)

DESCRIPTOR.message_types_by_name['UnitTest'] = _UNITTEST
DESCRIPTOR.message_types_by_name['Chatter'] = _CHATTER
DESCRIPTOR.message_types_by_name['ChatterBenchmark'] = _CHATTERBENCHMARK
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

UnitTest = _reflection.GeneratedProtocolMessageType('UnitTest', (_message.Message,), {
  'DESCRIPTOR' : _UNITTEST,
  '__module__' : 'cyber.proto.unit_test_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.UnitTest)
  })
_sym_db.RegisterMessage(UnitTest)

Chatter = _reflection.GeneratedProtocolMessageType('Chatter', (_message.Message,), {
  'DESCRIPTOR' : _CHATTER,
  '__module__' : 'cyber.proto.unit_test_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.Chatter)
  })
_sym_db.RegisterMessage(Chatter)

ChatterBenchmark = _reflection.GeneratedProtocolMessageType('ChatterBenchmark', (_message.Message,), {
  'DESCRIPTOR' : _CHATTERBENCHMARK,
  '__module__' : 'cyber.proto.unit_test_pb2'
  # @@protoc_insertion_point(class_scope:apollo.cyber.proto.ChatterBenchmark)
  })
_sym_db.RegisterMessage(ChatterBenchmark)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/relative_map/proto/relative_map_config.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/relative_map/proto/relative_map_config.proto',
  package='apollo.relative_map',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n8modules/map/relative_map/proto/relative_map_config.proto\x12\x13\x61pollo.relative_map\"\x7f\n\x12MapGenerationParam\x12 \n\x12\x64\x65\x66\x61ult_left_width\x18\x01 \x01(\x01:\x04\x31.75\x12!\n\x13\x64\x65\x66\x61ult_right_width\x18\x02 \x01(\x01:\x04\x31.75\x12$\n\x13\x64\x65\x66\x61ult_speed_limit\x18\x03 \x01(\x01:\x07\x32\x39.0576\"\xaa\x04\n\x14NavigationLaneConfig\x12$\n\x17min_lane_marker_quality\x18\x01 \x01(\x01:\x03\x30.5\x12I\n\x0blane_source\x18\x02 \x01(\x0e\x32\x34.apollo.relative_map.NavigationLaneConfig.LaneSource\x12)\n\x1cmax_len_from_navigation_line\x18\x03 \x01(\x01:\x03\x32\x35\x30\x12(\n\x1bmin_len_for_navigation_lane\x18\x04 \x01(\x01:\x03\x31\x35\x30\x12(\n\x1bmax_len_for_navigation_lane\x18\x05 \x01(\x01:\x03\x32\x35\x30\x12-\n\"ratio_navigation_lane_len_to_speed\x18\x06 \x01(\x01:\x01\x38\x12+\n\x1fmax_distance_to_navigation_line\x18\x07 \x01(\x01:\x02\x31\x35\x12.\n!min_view_range_to_use_lane_marker\x18\x08 \x01(\x01:\x03\x30.5\x12 \n\x13min_lane_half_width\x18\t \x01(\x01:\x03\x31.5\x12\x1e\n\x13max_lane_half_width\x18\n \x01(\x01:\x01\x32\x12\x1f\n\x12lane_marker_weight\x18\x0b \x01(\x01:\x03\x30.1\"3\n\nLaneSource\x12\x0e\n\nPERCEPTION\x10\x01\x12\x15\n\x11OFFLINE_GENERATED\x10\x02\"\x93\x01\n\x11RelativeMapConfig\x12:\n\tmap_param\x18\x01 \x01(\x0b\x32\'.apollo.relative_map.MapGenerationParam\x12\x42\n\x0fnavigation_lane\x18\x02 \x01(\x0b\x32).apollo.relative_map.NavigationLaneConfig'
)



_NAVIGATIONLANECONFIG_LANESOURCE = _descriptor.EnumDescriptor(
  name='LaneSource',
  full_name='apollo.relative_map.NavigationLaneConfig.LaneSource',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='PERCEPTION', index=0, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OFFLINE_GENERATED', index=1, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=714,
  serialized_end=765,
)
_sym_db.RegisterEnumDescriptor(_NAVIGATIONLANECONFIG_LANESOURCE)


_MAPGENERATIONPARAM = _descriptor.Descriptor(
  name='MapGenerationParam',
  full_name='apollo.relative_map.MapGenerationParam',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='default_left_width', full_name='apollo.relative_map.MapGenerationParam.default_left_width', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.75),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_right_width', full_name='apollo.relative_map.MapGenerationParam.default_right_width', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.75),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='default_speed_limit', full_name='apollo.relative_map.MapGenerationParam.default_speed_limit', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(29.0576),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=81,
  serialized_end=208,
)


_NAVIGATIONLANECONFIG = _descriptor.Descriptor(
  name='NavigationLaneConfig',
  full_name='apollo.relative_map.NavigationLaneConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='min_lane_marker_quality', full_name='apollo.relative_map.NavigationLaneConfig.min_lane_marker_quality', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_source', full_name='apollo.relative_map.NavigationLaneConfig.lane_source', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_len_from_navigation_line', full_name='apollo.relative_map.NavigationLaneConfig.max_len_from_navigation_line', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(250),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_len_for_navigation_lane', full_name='apollo.relative_map.NavigationLaneConfig.min_len_for_navigation_lane', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(150),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_len_for_navigation_lane', full_name='apollo.relative_map.NavigationLaneConfig.max_len_for_navigation_lane', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(250),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='ratio_navigation_lane_len_to_speed', full_name='apollo.relative_map.NavigationLaneConfig.ratio_navigation_lane_len_to_speed', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(8),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_distance_to_navigation_line', full_name='apollo.relative_map.NavigationLaneConfig.max_distance_to_navigation_line', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(15),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_view_range_to_use_lane_marker', full_name='apollo.relative_map.NavigationLaneConfig.min_view_range_to_use_lane_marker', index=7,
      number=8, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='min_lane_half_width', full_name='apollo.relative_map.NavigationLaneConfig.min_lane_half_width', index=8,
      number=9, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(1.5),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_lane_half_width', full_name='apollo.relative_map.NavigationLaneConfig.max_lane_half_width', index=9,
      number=10, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(2),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_marker_weight', full_name='apollo.relative_map.NavigationLaneConfig.lane_marker_weight', index=10,
      number=11, type=1, cpp_type=5, label=1,
      has_default_value=True, default_value=float(0.1),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _NAVIGATIONLANECONFIG_LANESOURCE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=211,
  serialized_end=765,
)


_RELATIVEMAPCONFIG = _descriptor.Descriptor(
  name='RelativeMapConfig',
  full_name='apollo.relative_map.RelativeMapConfig',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='map_param', full_name='apollo.relative_map.RelativeMapConfig.map_param', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='navigation_lane', full_name='apollo.relative_map.RelativeMapConfig.navigation_lane', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=768,
  serialized_end=915,
)

_NAVIGATIONLANECONFIG.fields_by_name['lane_source'].enum_type = _NAVIGATIONLANECONFIG_LANESOURCE
_NAVIGATIONLANECONFIG_LANESOURCE.containing_type = _NAVIGATIONLANECONFIG
_RELATIVEMAPCONFIG.fields_by_name['map_param'].message_type = _MAPGENERATIONPARAM
_RELATIVEMAPCONFIG.fields_by_name['navigation_lane'].message_type = _NAVIGATIONLANECONFIG
DESCRIPTOR.message_types_by_name['MapGenerationParam'] = _MAPGENERATIONPARAM
DESCRIPTOR.message_types_by_name['NavigationLaneConfig'] = _NAVIGATIONLANECONFIG
DESCRIPTOR.message_types_by_name['RelativeMapConfig'] = _RELATIVEMAPCONFIG
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MapGenerationParam = _reflection.GeneratedProtocolMessageType('MapGenerationParam', (_message.Message,), {
  'DESCRIPTOR' : _MAPGENERATIONPARAM,
  '__module__' : 'modules.map.relative_map.proto.relative_map_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.MapGenerationParam)
  })
_sym_db.RegisterMessage(MapGenerationParam)

NavigationLaneConfig = _reflection.GeneratedProtocolMessageType('NavigationLaneConfig', (_message.Message,), {
  'DESCRIPTOR' : _NAVIGATIONLANECONFIG,
  '__module__' : 'modules.map.relative_map.proto.relative_map_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.NavigationLaneConfig)
  })
_sym_db.RegisterMessage(NavigationLaneConfig)

RelativeMapConfig = _reflection.GeneratedProtocolMessageType('RelativeMapConfig', (_message.Message,), {
  'DESCRIPTOR' : _RELATIVEMAPCONFIG,
  '__module__' : 'modules.map.relative_map.proto.relative_map_config_pb2'
  # @@protoc_insertion_point(class_scope:apollo.relative_map.RelativeMapConfig)
  })
_sym_db.RegisterMessage(RelativeMapConfig)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/drivers/gnss/proto/heading.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.common.proto import header_pb2 as modules_dot_common_dot_proto_dot_header__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/drivers/gnss/proto/heading.proto',
  package='apollo.drivers.gnss',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n(modules/drivers/gnss/proto/heading.proto\x12\x13\x61pollo.drivers.gnss\x1a!modules/common/proto/header.proto\"\x87\x04\n\x07Heading\x12%\n\x06header\x18\x01 \x01(\x0b\x32\x15.apollo.common.Header\x12\x18\n\x10measurement_time\x18\x02 \x01(\x01\x12\x17\n\x0fsolution_status\x18\x03 \x01(\r\x12\x15\n\rposition_type\x18\x04 \x01(\r\x12\x17\n\x0f\x62\x61seline_length\x18\x05 \x01(\x02\x12\x0f\n\x07heading\x18\x06 \x01(\x02\x12\r\n\x05pitch\x18\x07 \x01(\x02\x12\x10\n\x08reserved\x18\x08 \x01(\x02\x12\x17\n\x0fheading_std_dev\x18\t \x01(\x02\x12\x15\n\rpitch_std_dev\x18\n \x01(\x02\x12\x12\n\nstation_id\x18\x0b \x01(\x0c\x12 \n\x18satellite_tracked_number\x18\x0c \x01(\r\x12\"\n\x1asatellite_soulution_number\x18\r \x01(\r\x12\x1c\n\x14satellite_number_obs\x18\x0e \x01(\r\x12\x1e\n\x16satellite_number_multi\x18\x0f \x01(\r\x12\x17\n\x0fsolution_source\x18\x10 \x01(\r\x12 \n\x18\x65xtended_solution_status\x18\x11 \x01(\r\x12\x1f\n\x17galileo_beidou_sig_mask\x18\x12 \x01(\r\x12\x1c\n\x14gps_glonass_sig_mask\x18\x13 \x01(\r'
  ,
  dependencies=[modules_dot_common_dot_proto_dot_header__pb2.DESCRIPTOR,])




_HEADING = _descriptor.Descriptor(
  name='Heading',
  full_name='apollo.drivers.gnss.Heading',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='apollo.drivers.gnss.Heading.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='measurement_time', full_name='apollo.drivers.gnss.Heading.measurement_time', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solution_status', full_name='apollo.drivers.gnss.Heading.solution_status', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='position_type', full_name='apollo.drivers.gnss.Heading.position_type', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baseline_length', full_name='apollo.drivers.gnss.Heading.baseline_length', index=4,
      number=5, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading', full_name='apollo.drivers.gnss.Heading.heading', index=5,
      number=6, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pitch', full_name='apollo.drivers.gnss.Heading.pitch', index=6,
      number=7, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reserved', full_name='apollo.drivers.gnss.Heading.reserved', index=7,
      number=8, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='heading_std_dev', full_name='apollo.drivers.gnss.Heading.heading_std_dev', index=8,
      number=9, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pitch_std_dev', full_name='apollo.drivers.gnss.Heading.pitch_std_dev', index=9,
      number=10, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='station_id', full_name='apollo.drivers.gnss.Heading.station_id', index=10,
      number=11, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_tracked_number', full_name='apollo.drivers.gnss.Heading.satellite_tracked_number', index=11,
      number=12, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_soulution_number', full_name='apollo.drivers.gnss.Heading.satellite_soulution_number', index=12,
      number=13, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_number_obs', full_name='apollo.drivers.gnss.Heading.satellite_number_obs', index=13,
      number=14, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='satellite_number_multi', full_name='apollo.drivers.gnss.Heading.satellite_number_multi', index=14,
      number=15, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='solution_source', full_name='apollo.drivers.gnss.Heading.solution_source', index=15,
      number=16, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='extended_solution_status', full_name='apollo.drivers.gnss.Heading.extended_solution_status', index=16,
      number=17, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='galileo_beidou_sig_mask', full_name='apollo.drivers.gnss.Heading.galileo_beidou_sig_mask', index=17,
      number=18, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='gps_glonass_sig_mask', full_name='apollo.drivers.gnss.Heading.gps_glonass_sig_mask', index=18,
      number=19, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=101,
  serialized_end=620,
)

_HEADING.fields_by_name['header'].message_type = modules_dot_common_dot_proto_dot_header__pb2._HEADER
DESCRIPTOR.message_types_by_name['Heading'] = _HEADING
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Heading = _reflection.GeneratedProtocolMessageType('Heading', (_message.Message,), {
  'DESCRIPTOR' : _HEADING,
  '__module__' : 'modules.drivers.gnss.proto.heading_pb2'
  # @@protoc_insertion_point(class_scope:apollo.drivers.gnss.Heading)
  })
_sym_db.RegisterMessage(Heading)


# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: modules/map/proto/map_overlap.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from modules.map.proto import map_id_pb2 as modules_dot_map_dot_proto_dot_map__id__pb2
from modules.map.proto import map_geometry_pb2 as modules_dot_map_dot_proto_dot_map__geometry__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='modules/map/proto/map_overlap.proto',
  package='apollo.hdmap',
  syntax='proto2',
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n#modules/map/proto/map_overlap.proto\x12\x0c\x61pollo.hdmap\x1a\x1emodules/map/proto/map_id.proto\x1a$modules/map/proto/map_geometry.proto\"p\n\x0fLaneOverlapInfo\x12\x0f\n\x07start_s\x18\x01 \x01(\x01\x12\r\n\x05\x65nd_s\x18\x02 \x01(\x01\x12\x10\n\x08is_merge\x18\x03 \x01(\x08\x12+\n\x11region_overlap_id\x18\x04 \x01(\x0b\x32\x10.apollo.hdmap.Id\"\x13\n\x11SignalOverlapInfo\"\x15\n\x13StopSignOverlapInfo\"C\n\x14\x43rosswalkOverlapInfo\x12+\n\x11region_overlap_id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\"\x15\n\x13JunctionOverlapInfo\"\x12\n\x10YieldOverlapInfo\"\x16\n\x14\x43learAreaOverlapInfo\"\x16\n\x14SpeedBumpOverlapInfo\"\x19\n\x17ParkingSpaceOverlapInfo\"\x18\n\x16PNCJunctionOverlapInfo\"\x10\n\x0eRSUOverlapInfo\"Y\n\x11RegionOverlapInfo\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12&\n\x07polygon\x18\x02 \x03(\x0b\x32\x15.apollo.hdmap.Polygon\"\xaf\x06\n\x11ObjectOverlapInfo\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12:\n\x11lane_overlap_info\x18\x03 \x01(\x0b\x32\x1d.apollo.hdmap.LaneOverlapInfoH\x00\x12>\n\x13signal_overlap_info\x18\x04 \x01(\x0b\x32\x1f.apollo.hdmap.SignalOverlapInfoH\x00\x12\x43\n\x16stop_sign_overlap_info\x18\x05 \x01(\x0b\x32!.apollo.hdmap.StopSignOverlapInfoH\x00\x12\x44\n\x16\x63rosswalk_overlap_info\x18\x06 \x01(\x0b\x32\".apollo.hdmap.CrosswalkOverlapInfoH\x00\x12\x42\n\x15junction_overlap_info\x18\x07 \x01(\x0b\x32!.apollo.hdmap.JunctionOverlapInfoH\x00\x12\x41\n\x17yield_sign_overlap_info\x18\x08 \x01(\x0b\x32\x1e.apollo.hdmap.YieldOverlapInfoH\x00\x12\x45\n\x17\x63lear_area_overlap_info\x18\t \x01(\x0b\x32\".apollo.hdmap.ClearAreaOverlapInfoH\x00\x12\x45\n\x17speed_bump_overlap_info\x18\n \x01(\x0b\x32\".apollo.hdmap.SpeedBumpOverlapInfoH\x00\x12K\n\x1aparking_space_overlap_info\x18\x0b \x01(\x0b\x32%.apollo.hdmap.ParkingSpaceOverlapInfoH\x00\x12I\n\x19pnc_junction_overlap_info\x18\x0c \x01(\x0b\x32$.apollo.hdmap.PNCJunctionOverlapInfoH\x00\x12\x38\n\x10rsu_overlap_info\x18\r \x01(\x0b\x32\x1c.apollo.hdmap.RSUOverlapInfoH\x00\x42\x0e\n\x0coverlap_info\"\x91\x01\n\x07Overlap\x12\x1c\n\x02id\x18\x01 \x01(\x0b\x32\x10.apollo.hdmap.Id\x12/\n\x06object\x18\x02 \x03(\x0b\x32\x1f.apollo.hdmap.ObjectOverlapInfo\x12\x37\n\x0eregion_overlap\x18\x03 \x03(\x0b\x32\x1f.apollo.hdmap.RegionOverlapInfo'
  ,
  dependencies=[modules_dot_map_dot_proto_dot_map__id__pb2.DESCRIPTOR,modules_dot_map_dot_proto_dot_map__geometry__pb2.DESCRIPTOR,])




_LANEOVERLAPINFO = _descriptor.Descriptor(
  name='LaneOverlapInfo',
  full_name='apollo.hdmap.LaneOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_s', full_name='apollo.hdmap.LaneOverlapInfo.start_s', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_s', full_name='apollo.hdmap.LaneOverlapInfo.end_s', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_merge', full_name='apollo.hdmap.LaneOverlapInfo.is_merge', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region_overlap_id', full_name='apollo.hdmap.LaneOverlapInfo.region_overlap_id', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=235,
)


_SIGNALOVERLAPINFO = _descriptor.Descriptor(
  name='SignalOverlapInfo',
  full_name='apollo.hdmap.SignalOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=256,
)


_STOPSIGNOVERLAPINFO = _descriptor.Descriptor(
  name='StopSignOverlapInfo',
  full_name='apollo.hdmap.StopSignOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=258,
  serialized_end=279,
)


_CROSSWALKOVERLAPINFO = _descriptor.Descriptor(
  name='CrosswalkOverlapInfo',
  full_name='apollo.hdmap.CrosswalkOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='region_overlap_id', full_name='apollo.hdmap.CrosswalkOverlapInfo.region_overlap_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=281,
  serialized_end=348,
)


_JUNCTIONOVERLAPINFO = _descriptor.Descriptor(
  name='JunctionOverlapInfo',
  full_name='apollo.hdmap.JunctionOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=350,
  serialized_end=371,
)


_YIELDOVERLAPINFO = _descriptor.Descriptor(
  name='YieldOverlapInfo',
  full_name='apollo.hdmap.YieldOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=373,
  serialized_end=391,
)


_CLEARAREAOVERLAPINFO = _descriptor.Descriptor(
  name='ClearAreaOverlapInfo',
  full_name='apollo.hdmap.ClearAreaOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=393,
  serialized_end=415,
)


_SPEEDBUMPOVERLAPINFO = _descriptor.Descriptor(
  name='SpeedBumpOverlapInfo',
  full_name='apollo.hdmap.SpeedBumpOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=417,
  serialized_end=439,
)


_PARKINGSPACEOVERLAPINFO = _descriptor.Descriptor(
  name='ParkingSpaceOverlapInfo',
  full_name='apollo.hdmap.ParkingSpaceOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=441,
  serialized_end=466,
)


_PNCJUNCTIONOVERLAPINFO = _descriptor.Descriptor(
  name='PNCJunctionOverlapInfo',
  full_name='apollo.hdmap.PNCJunctionOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=468,
  serialized_end=492,
)


_RSUOVERLAPINFO = _descriptor.Descriptor(
  name='RSUOverlapInfo',
  full_name='apollo.hdmap.RSUOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=494,
  serialized_end=510,
)


_REGIONOVERLAPINFO = _descriptor.Descriptor(
  name='RegionOverlapInfo',
  full_name='apollo.hdmap.RegionOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.RegionOverlapInfo.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polygon', full_name='apollo.hdmap.RegionOverlapInfo.polygon', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=512,
  serialized_end=601,
)


_OBJECTOVERLAPINFO = _descriptor.Descriptor(
  name='ObjectOverlapInfo',
  full_name='apollo.hdmap.ObjectOverlapInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.ObjectOverlapInfo.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lane_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.lane_overlap_info', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='signal_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.signal_overlap_info', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stop_sign_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.stop_sign_overlap_info', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='crosswalk_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.crosswalk_overlap_info', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='junction_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.junction_overlap_info', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='yield_sign_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.yield_sign_overlap_info', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear_area_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.clear_area_overlap_info', index=7,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='speed_bump_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.speed_bump_overlap_info', index=8,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parking_space_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.parking_space_overlap_info', index=9,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pnc_junction_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.pnc_junction_overlap_info', index=10,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rsu_overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.rsu_overlap_info', index=11,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='overlap_info', full_name='apollo.hdmap.ObjectOverlapInfo.overlap_info',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=604,
  serialized_end=1419,
)


_OVERLAP = _descriptor.Descriptor(
  name='Overlap',
  full_name='apollo.hdmap.Overlap',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='apollo.hdmap.Overlap.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='object', full_name='apollo.hdmap.Overlap.object', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='region_overlap', full_name='apollo.hdmap.Overlap.region_overlap', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1422,
  serialized_end=1567,
)

_LANEOVERLAPINFO.fields_by_name['region_overlap_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_CROSSWALKOVERLAPINFO.fields_by_name['region_overlap_id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_REGIONOVERLAPINFO.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_REGIONOVERLAPINFO.fields_by_name['polygon'].message_type = modules_dot_map_dot_proto_dot_map__geometry__pb2._POLYGON
_OBJECTOVERLAPINFO.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_OBJECTOVERLAPINFO.fields_by_name['lane_overlap_info'].message_type = _LANEOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['signal_overlap_info'].message_type = _SIGNALOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['stop_sign_overlap_info'].message_type = _STOPSIGNOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['crosswalk_overlap_info'].message_type = _CROSSWALKOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['junction_overlap_info'].message_type = _JUNCTIONOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['yield_sign_overlap_info'].message_type = _YIELDOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['clear_area_overlap_info'].message_type = _CLEARAREAOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['speed_bump_overlap_info'].message_type = _SPEEDBUMPOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['parking_space_overlap_info'].message_type = _PARKINGSPACEOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['pnc_junction_overlap_info'].message_type = _PNCJUNCTIONOVERLAPINFO
_OBJECTOVERLAPINFO.fields_by_name['rsu_overlap_info'].message_type = _RSUOVERLAPINFO
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['lane_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['lane_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['signal_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['signal_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['stop_sign_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['stop_sign_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['crosswalk_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['crosswalk_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['junction_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['junction_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['yield_sign_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['yield_sign_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['clear_area_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['clear_area_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['speed_bump_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['speed_bump_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['parking_space_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['parking_space_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['pnc_junction_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['pnc_junction_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OBJECTOVERLAPINFO.oneofs_by_name['overlap_info'].fields.append(
  _OBJECTOVERLAPINFO.fields_by_name['rsu_overlap_info'])
_OBJECTOVERLAPINFO.fields_by_name['rsu_overlap_info'].containing_oneof = _OBJECTOVERLAPINFO.oneofs_by_name['overlap_info']
_OVERLAP.fields_by_name['id'].message_type = modules_dot_map_dot_proto_dot_map__id__pb2._ID
_OVERLAP.fields_by_name['object'].message_type = _OBJECTOVERLAPINFO
_OVERLAP.fields_by_name['region_overlap'].message_type = _REGIONOVERLAPINFO
DESCRIPTOR.message_types_by_name['LaneOverlapInfo'] = _LANEOVERLAPINFO
DESCRIPTOR.message_types_by_name['SignalOverlapInfo'] = _SIGNALOVERLAPINFO
DESCRIPTOR.message_types_by_name['StopSignOverlapInfo'] = _STOPSIGNOVERLAPINFO
DESCRIPTOR.message_types_by_name['CrosswalkOverlapInfo'] = _CROSSWALKOVERLAPINFO
DESCRIPTOR.message_types_by_name['JunctionOverlapInfo'] = _JUNCTIONOVERLAPINFO
DESCRIPTOR.message_types_by_name['YieldOverlapInfo'] = _YIELDOVERLAPINFO
DESCRIPTOR.message_types_by_name['ClearAreaOverlapInfo'] = _CLEARAREAOVERLAPINFO
DESCRIPTOR.message_types_by_name['SpeedBumpOverlapInfo'] = _SPEEDBUMPOVERLAPINFO
DESCRIPTOR.message_types_by_name['ParkingSpaceOverlapInfo'] = _PARKINGSPACEOVERLAPINFO
DESCRIPTOR.message_types_by_name['PNCJunctionOverlapInfo'] = _PNCJUNCTIONOVERLAPINFO
DESCRIPTOR.message_types_by_name['RSUOverlapInfo'] = _RSUOVERLAPINFO
DESCRIPTOR.message_types_by_name['RegionOverlapInfo'] = _REGIONOVERLAPINFO
DESCRIPTOR.message_types_by_name['ObjectOverlapInfo'] = _OBJECTOVERLAPINFO
DESCRIPTOR.message_types_by_name['Overlap'] = _OVERLAP
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LaneOverlapInfo = _reflection.GeneratedProtocolMessageType('LaneOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _LANEOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.LaneOverlapInfo)
  })
_sym_db.RegisterMessage(LaneOverlapInfo)

SignalOverlapInfo = _reflection.GeneratedProtocolMessageType('SignalOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _SIGNALOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.SignalOverlapInfo)
  })
_sym_db.RegisterMessage(SignalOverlapInfo)

StopSignOverlapInfo = _reflection.GeneratedProtocolMessageType('StopSignOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _STOPSIGNOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.StopSignOverlapInfo)
  })
_sym_db.RegisterMessage(StopSignOverlapInfo)

CrosswalkOverlapInfo = _reflection.GeneratedProtocolMessageType('CrosswalkOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _CROSSWALKOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.CrosswalkOverlapInfo)
  })
_sym_db.RegisterMessage(CrosswalkOverlapInfo)

JunctionOverlapInfo = _reflection.GeneratedProtocolMessageType('JunctionOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _JUNCTIONOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.JunctionOverlapInfo)
  })
_sym_db.RegisterMessage(JunctionOverlapInfo)

YieldOverlapInfo = _reflection.GeneratedProtocolMessageType('YieldOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _YIELDOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.YieldOverlapInfo)
  })
_sym_db.RegisterMessage(YieldOverlapInfo)

ClearAreaOverlapInfo = _reflection.GeneratedProtocolMessageType('ClearAreaOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLEARAREAOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.ClearAreaOverlapInfo)
  })
_sym_db.RegisterMessage(ClearAreaOverlapInfo)

SpeedBumpOverlapInfo = _reflection.GeneratedProtocolMessageType('SpeedBumpOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _SPEEDBUMPOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.SpeedBumpOverlapInfo)
  })
_sym_db.RegisterMessage(SpeedBumpOverlapInfo)

ParkingSpaceOverlapInfo = _reflection.GeneratedProtocolMessageType('ParkingSpaceOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _PARKINGSPACEOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.ParkingSpaceOverlapInfo)
  })
_sym_db.RegisterMessage(ParkingSpaceOverlapInfo)

PNCJunctionOverlapInfo = _reflection.GeneratedProtocolMessageType('PNCJunctionOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _PNCJUNCTIONOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.PNCJunctionOverlapInfo)
  })
_sym_db.RegisterMessage(PNCJunctionOverlapInfo)

RSUOverlapInfo = _reflection.GeneratedProtocolMessageType('RSUOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _RSUOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.RSUOverlapInfo)
  })
_sym_db.RegisterMessage(RSUOverlapInfo)

RegionOverlapInfo = _reflection.GeneratedProtocolMessageType('RegionOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _REGIONOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.RegionOverlapInfo)
  })
_sym_db.RegisterMessage(RegionOverlapInfo)

ObjectOverlapInfo = _reflection.GeneratedProtocolMessageType('ObjectOverlapInfo', (_message.Message,), {
  'DESCRIPTOR' : _OBJECTOVERLAPINFO,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.ObjectOverlapInfo)
  })
_sym_db.RegisterMessage(ObjectOverlapInfo)

Overlap = _reflection.GeneratedProtocolMessageType('Overlap', (_message.Message,), {
  'DESCRIPTOR' : _OVERLAP,
  '__module__' : 'modules.map.proto.map_overlap_pb2'
  # @@protoc_insertion_point(class_scope:apollo.hdmap.Overlap)
  })
_sym_db.RegisterMessage(Overlap)


# @@protoc_insertion_point(module_scope)
